"""
Module for setting up the project.
"""

from setuptools import find_packages, setup

setup(
    name="chamco_ragbot",
    version="0.1.39",
    packages=find_packages(exclude=["tests*"]),
    license="MIT",
    description=" ",
    author="Ibrahim Animashaun",
)